#include "allcrypto.h"
#include <string.h>

/*include add the specific crypto types*/
#include "noenc/noenc.h"
#include "twofish/twofishinc.h"

/********************************************************
*  Set up everything in the beginning
********************************************************/
void CryptoInit(){
	bzero(Cryptos, sizeof(CryptoRecord)*MAX_CRYPTO_RECORDS);
}

/********************************************************
*  Close up and clean up everything
********************************************************/
void CryptoClose(){
	int	i;
	for (i=0;i<MAX_CRYPTO_RECORDS;i++){
		RemoveKey(&Cryptos[i]);
	}
}


/********************************************************
*  Given an IP return the stuff to decrypt the packet
*  Return NULL is not found
********************************************************/
CryptoRecord*	GetCryptoFromID(int ID){
	int i;
	
	for (i=0;i<MAX_CRYPTO_RECORDS;i++){
		if (ID==Cryptos[i].ID) return &Cryptos[i];
	}
	
	return NULL;
}

/********************************************************
*  Add a new key
*  returns KeyID on success
*  returns -1 on failure
********************************************************/
int	AddKey(char CryptoType, int ID, char* KeyString){
	int i;
	
	/*find a free record*/
	for (i=0;i<MAX_CRYPTO_RECORDS;i++){
		if (!Cryptos[i].InUse) break;
	}
	if (i==MAX_CRYPTO_RECORDS) return -1;

	switch (CryptoType){
	case CRYPTO_TYPE_NONE:
		return AddKeyNoEnc(&Cryptos[i], ID, KeyString);
	case CRYPTO_TYPE_TWOFISH:
		return AddKeyTwoFish(&Cryptos[i], ID, KeyString);
	default:
		printf("I don't understand that type of key\n");
	}
}

/********************************************************
*  removes a key and frees resources
********************************************************/
void RemoveKey(CryptoRecord* cr){
	if (!cr->InUse) return;
	
	switch (cr->CryptoType){
	default:
		printf("I don't understand that type of key\n");
	}
}

/********************************************************
*  Display raw data on the screen as a hexdump
********************************************************/
void DumpData(unsigned char* Data, int DataLen){
	int i,j,k;
	char	Line[80];
	
	
	bzero(Line, 80);
	Line[16*3+0]=' ';
	Line[16*3+1]=' ';
	Line[16*3+2]=' ';
	Line[16*3+3]=' ';
	j=0;
	printf("starting...\n");
	for (i=0;i<DataLen; i++){;
		sprintf(&Line[j*3], "%02X ", Data[i]);
		switch (Data[i]){
		case 0x00:
		case 0x13:
		case 0x09:
		case 0x04:
		case 0x0A:
		case 0x0C:
		case 0X0D:
		case 0xDE:
		case 0xEE:
			Line[(16*3)+4+j+1]='*';
			break;
		default:
			Line[(16*3)+j+1]=Data[i];
		}
		j++;
		if (j>15){
			Line[16*3]=' ';
			printf("%s\n",Line);
			bzero(Line, 80);
			for (k=1;k<79;k++) Line[k]=' ';
			j=0;
		}	
		
	}
	printf("Ending...\n");

}
