#ifndef __SPP_SESSION_H__
#define __SPP_SESSION_H__

/*******************************************
* Assigns a unique session ID to each
* conversation
********************************************/
#include "snort.h"

/*put these in config when done*/
#define NUM_STATES			65535
#define STATE_HASH_SIZE		65535
#define STATE_TIMEOUT		120
#define MAX_STATE_WALK		1024

#define NUM_CACHE			1024
#define PACKET_SIZE			600
#define MAX_CACHE_WALK		20

typedef struct packet_holder{
	struct packet_holder*	next;	/*in ring order*/
	struct packet_holder*	cache_next;	
	struct packet_holder**	cache_prev;
	
	int						len;
	char					payload[PACKET_SIZE];
	unsigned int			seq;
} PacketHolder;

typedef struct state_record{
	unsigned long		session_id;

	struct in_addr			SIP;
	struct in_addr			DIP;
	unsigned short			sp;
	unsigned short			dp;
	unsigned char			protocol;
	unsigned long			src_seq;
	unsigned long			dst_seq;
	unsigned long			last_time;
	
	struct state_record*	next; /*in ring order*/
	struct state_record*	hash_next;
	struct state_record**	hash_prev;
	
	PacketHolder*			cache; /*cached packets*/
} StateRecord;

void SetupConv();
void ConvInit(u_char* args);
void ConvFunc(Packet* p);
int	CachePacket(StateRecord* s, Packet*	p);
PacketHolder* GetCachePacket(StateRecord* s, unsigned int seq); 


#endif
